@@ -35,7 +35,7 @@ BEGIN
 }
 
 # module/package version
-$VERSION = '0.36';
+$VERSION = '0.37';
 
 # file creation mode (octal, a la chmod)
 $FILEMODE = 0660;
@@ -514,6 +514,12 @@ sub send_email {
         $smtp->datasend("Reply-To: $recipient\n")
             or return "Unable to send email data.";
     }
+    $smtp->datasend("MIME-Version: 1.0\n")
+        or return "Unable to send email data.";
+    $smtp->datasend("Content-Type: text/plain\n")
+        or return "Unable to send email data.";
+    $smtp->datasend("Content-Transfer-Encoding: 7bit\n")
+        or return "Unable to send email data.";
     $smtp->datasend("\n")
         or return "Unable to send email data.";
     $smtp->datasend(@_)
